# we don't want to provide private python extension libs
%define _exclude_files_from_autoprov %{python_sitearch}/.*\\.so\\|%{python3_sitearch}/.*\\.so

%define enable_atlas 0
%{?_with_atlas: %global enable_atlas 1}
%define enable_doc 0

%define module	scipy
%define name	python-%{module}
%define version 0.13.0
%define release %mkrel 4

%define Werror_cflags %nil

Summary:	Scientific tools for Python
Name:		%{name}
Group:		Development/Python
Version:	%{version}
Release:	%{release}
License:	BSD
Url:		http://www.scipy.org

Source0:	http://downloads.sourceforge.net/scipy/%{module}-%{version}.tar.gz


Obsoletes:	python-SciPy <= %{version}-%{release}
Obsoletes:	python-symeig <= %{version}%{release}
Requires:	python-numpy >= 1.7.1
Requires:	python-numpy-devel
Requires:	gcc-gfortran >= 4.0
Requires:	gcc-c++
Requires:	pkgconfig(python)

BuildRequires:	swig
%if %enable_atlas
BuildRequires:	libatlas-devel
%else
BuildRequires:	blas-devel
%endif 
BuildRequires:	lapack-devel 
BuildRequires:	python-numpy-devel >= 1.7.1
BuildRequires:	gcc-gfortran >= 4.0
BuildRequires:	netcdf-devel
BuildRequires:	python-nose
BuildRequires:	pkgconfig(python)
BuildRequires:	suitesparse-devel
BuildRequires:	python-six
%if %enable_doc
BuildRequires:	python-sphinx
BuildRequires:	python-matplotlib
%endif
BuildRequires:	python-cython
BuildRequires:	python-setuptools
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-setuptools 
BuildRequires:	python3-numpy-devel >= 1.7.1
BuildRequires:	python3-nose
BuildRequires:	python3-six

%description
SciPy is an open source library of scientific tools for Python. SciPy
supplements the popular numpy module, gathering a variety of high
level science and engineering modules together as a single
package. SciPy includes modules for graphics and plotting,
optimization, integration, special functions, signal and image
processing, genetic algorithms, ODE solvers, and others.

%package -n python3-scipy
Summary:	Scipy: Scientific Tools for Python
Group:		Development/Python
License:	BSD and LGPLv2+
Requires:	python3-numpy
Requires:	python3-numpy-devel
Requires:	pkgconfig(python3)

%description -n python3-scipy
Scipy is open-source software for mathematics, science, and
engineering. The core library is NumPy which provides convenient and
fast N-dimensional array manipulation. The SciPy library is built to
work with NumPy arrays, and provides many user-friendly and efficient
numerical routines such as routines for numerical integration and
optimization. Together, they run on all popular operating systems, are
quick to install, and are free of charge. NumPy and SciPy are easy to
use, but powerful enough to be depended upon by some of the world's
leading scientists and engineers.

%prep
%setup -q -n %{module}-%{version}
# Bundled libs
rm scipy/lib/six.py
find -name \*.py | xargs sed -i -e 's/scipy\.lib\.six/six/'
cat > site.cfg << EOF

[amd]
library_dirs = %{_libdir}
include_dirs = /usr/include/suitesparse
amd_libs = amd

[umfpack]
library_dirs = %{_libdir}
include_dirs = /usr/include/suitesparse
umfpack_libs = umfpack
EOF

rm -rf %{py3dir}
cp -a . %{py3dir}

%build

%if %enable_atlas
%define extraflags ""
%else
%define extraflags "-DNO_ATLAS_INFO"
%endif


# Make sure that gcc 4 is being used to build the package:
GCC_VERSION=`gcc --version | awk 'NR == 1 {print $3}'`
if echo $GCC_VERSION | grep ^4 > /dev/null; then
   export CC=gcc-$GCC_VERSION
else
   echo "Need GCC 4 to build"
   exit 1
fi

export CC=gcc-$GCC_VERSION

pushd %{py3dir}
env FFLAGS="%{optflags} -fPIC -O3 %extraflags" \
    CFLAGS="%{optflags} -fPIC -O3 %extraflags" \
    ATLAS=%{_libdir}/atlas FFTW=%{_libdir} BLAS=%{_libdir} LAPACK=%{_libdir} \
    %{__python3} setup.py config_fc --fcompiler=gnu95 --noarch build

popd

env FFLAGS="%{optflags} -fPIC -O3 %extraflags" \
    CFLAGS="%{optflags} -fPIC -O3 %extraflags" \
    ATLAS=%{_libdir}/atlas FFTW=%{_libdir} BLAS=%{_libdir} LAPACK=%{_libdir} \
    %{__python} setup.py config_fc --fcompiler=gnu95 --noarch build

%if %enable_doc
pushd doc
export PYTHONPATH=`dir -d ../build/lib.linux*`
%__make html
popd
%endif

%install
# first install python3 so the binaries are overwritten by the python2 ones
pushd %{py3dir}
env FFLAGS="%{optflags} -fPIC -O3 %extraflags" \
    CFLAGS="%{optflags} -fPIC -O3 %extraflags" \
    ATLAS=%{_libdir}/atlas FFTW=%{_libdir} BLAS=%{_libdir} LAPACK=%{_libdir} \
    %{__python3} setup.py install --root=%{buildroot}

popd

env FFLAGS="%{optflags} -fPIC -O3 %extraflags" \
    CFLAGS="%{optflags} -fPIC -O3 %extraflags" \
    ATLAS=%{_libdir}/atlas FFTW=%{_libdir} BLAS=%{_libdir} LAPACK=%{_libdir} \
    %{__python} setup.py install --root=%{buildroot} 


# Remove doc files that should be in %%doc:
%__rm -f %{buildroot}%{py_platsitedir}/%{module}/*.txt

%check
pushd %{py3dir}
mkdir test
cd test
PYTHONPATH=$RPM_BUILD_ROOT%{python3_sitearch} %{__python3} -c "import scipy; scipy.test('full')"
popd

mkdir test
cd test
PYTHONPATH=%{buildroot}%{py_platsitedir} %{__python} -c "import scipy; scipy.test('full')"

%files
%doc LICENSE.txt 
%dir %{py_platsitedir}/%{module}
%{py_platsitedir}/%{module}/*
%{py_platsitedir}/%{module}-*.egg-info

%files -n python3-scipy
%doc LICENSE.txt
%{python3_sitearch}/%{module}/*
%{python3_sitearch}/*.egg-info



%changelog
* Tue Nov 19 2013 philippem <philippem> 0.13.0-4.mga4
+ Revision: 551935
- add requires on python-devel

* Wed Nov 13 2013 philippem <philippem> 0.13.0-3.mga4
+ Revision: 551061
- add missing requires

* Fri Nov 01 2013 philippem <philippem> 0.13.0-2.mga4
+ Revision: 548720
- add missing requires

* Tue Oct 29 2013 philippem <philippem> 0.13.0-1.mga4
+ Revision: 547868
- Update to 0.13.0
- Update to 0.13.0

* Tue Oct 22 2013 umeabot <umeabot> 0.12.0-5.mga4
+ Revision: 546139
- Mageia 4 Mass Rebuild

* Thu Oct 17 2013 philippem <philippem> 0.12.0-4.mga4
+ Revision: 502197
- fix dependencies

* Tue Oct 15 2013 pterjan <pterjan> 0.12.0-3.mga4
+ Revision: 499335
- Rebuild to add different pythonegg provides for python 2 and 3

  + philippem <philippem>
    - cleaning spec

* Mon Jul 01 2013 philippem <philippem> 0.12.0-1.mga4
+ Revision: 449510
- fix group, add Python 3 tests
- add python 3
- update to 0.12.0

* Fri Mar 29 2013 eatdirt <eatdirt> 0.9.0-6.mga3
+ Revision: 406070
- Remove dependence to ATLAS, fix compilation failure

* Sun Jan 13 2013 umeabot <umeabot> 0.9.0-5.mga3
+ Revision: 379476
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 23 2012 barjac <barjac> 0.9.0-4.mga3
+ Revision: 334137
- rebuild for new umfpack
- spec clean

* Tue Jun 21 2011 ahmad <ahmad> 0.9.0-3.mga2
+ Revision: 110919
- Rebuild against the new umfpack lib major

* Tue May 10 2011 ahmad <ahmad> 0.9.0-2.mga1
+ Revision: 96865
- Drop old/unneeded scriptlets
- Drop the buildroot declaration
- imported package python-scipy

